@@ -36,7 +36,7 @@ SAMPLE_DATA = {
                        'resourcemanager'],
     'node_configs': {
         'HDFS': {
-            u'mapreduce.task.tmp.dir': '/temp/'
+            'mapreduce.task.tmp.dir': '/temp/'
         }
     },
     'image_id': '550e8400-e29b-41d4-a716-446655440000',
