@@ -13,16 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import uuidutils
 import six
 
 from sahara import conductor as c
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
+from sahara.service.castellan import utils as key_manager
 from sahara.service.edp import job_utils
 from sahara.service import trusts as t
 from sahara.swift import utils as su
@@ -46,7 +47,7 @@ opts = [
                help='The domain Sahara will use to create new proxy users '
                     'for Swift object access.'),
     cfg.ListOpt('proxy_user_role_names',
-                default=['Member'],
+                default=['member'],
                 help='A list of the role names that the proxy user should '
                      'assume through trust for Swift object access.')
 ]
@@ -60,7 +61,7 @@ def create_proxy_user_for_job_execution(job_execution):
 
     '''
     username = 'job_{0}'.format(job_execution.id)
-    password = proxy_user_create(username)
+    password = key_manager.store_secret(proxy_user_create(username))
     current_user = k.auth()
     proxy_user = k.auth_for_proxy(username, password)
     trust_id = t.create_trust(trustor=current_user,
@@ -85,13 +86,14 @@ def delete_proxy_user_for_job_execution(job_execution):
     proxy_configs = job_execution.job_configs.get('proxy_configs')
     if proxy_configs is not None:
         proxy_username = proxy_configs.get('proxy_username')
-        proxy_password = proxy_configs.get('proxy_password')
         proxy_trust_id = proxy_configs.get('proxy_trust_id')
         proxy_user = k.auth_for_proxy(proxy_username,
-                                      proxy_password,
+                                      key_manager.get_secret(
+                                          proxy_configs.get('proxy_password')),
                                       proxy_trust_id)
         t.delete_trust(proxy_user, proxy_trust_id)
         proxy_user_delete(proxy_username)
+        key_manager.delete_secret(proxy_configs.get('proxy_password'))
         update = job_execution.job_configs.to_dict()
         del update['proxy_configs']
         return update
@@ -107,7 +109,7 @@ def create_proxy_user_for_cluster(cluster):
     if cluster.cluster_configs.get('proxy_configs'):
         return cluster
     username = 'cluster_{0}'.format(cluster.id)
-    password = proxy_user_create(username)
+    password = key_manager.store_secret(proxy_user_create(username))
     current_user = k.auth()
     proxy_user = k.auth_for_proxy(username, password)
     trust_id = t.create_trust(trustor=current_user,
@@ -131,13 +133,14 @@ def delete_proxy_user_for_cluster(cluster):
     proxy_configs = cluster.cluster_configs.get('proxy_configs')
     if proxy_configs is not None:
         proxy_username = proxy_configs.get('proxy_username')
-        proxy_password = proxy_configs.get('proxy_password')
         proxy_trust_id = proxy_configs.get('proxy_trust_id')
         proxy_user = k.auth_for_proxy(proxy_username,
-                                      proxy_password,
+                                      key_manager.get_secret(
+                                          proxy_configs.get('proxy_password')),
                                       proxy_trust_id)
         t.delete_trust(proxy_user, proxy_trust_id)
         proxy_user_delete(proxy_username)
+        key_manager.delete_secret(proxy_configs.get('proxy_password'))
         update = {'cluster_configs': cluster.cluster_configs.to_dict()}
         del update['cluster_configs']['proxy_configs']
         conductor.cluster_update(context.ctx(), cluster, update)
@@ -264,7 +267,7 @@ def proxy_user_create(username):
     '''
     admin = k.client_for_admin()
     domain = domain_for_proxy()
-    password = six.text_type(uuid.uuid4())
+    password = uuidutils.generate_uuid()
     b.execute_with_retries(
         admin.users.create, name=username, password=password, domain=domain.id)
     LOG.debug('Created proxy user {username}'.format(username=username))
